@@ -21,6 +21,7 @@
 from datetime import datetime
 
 # Import from itools
+from csv_ import CSVFile
 from itools.datatypes import DateTime, String, Integer, Unicode
 from itools.handlers import File
 from itools import vfs
@@ -898,3 +899,34 @@ class Table(File):
                     record[key] = line[index]
             self.add_record(record)
 
+
+    def to_csv(self, columns, separator=None, language=None):
+        """Export the table to CSV handler.
+        As table columns are unordered, the order comes from the "columns"
+        parameter.
+        separator: join multiple values with this string
+        language: affects multilingual columns
+        """
+        csv = CSVFile()
+
+        for record in self.get_records():
+            line = []
+            for column in columns:
+                datatype = self.get_record_datatype(column)
+                value = self.get_record_value(record, column,
+                                              language=language)
+                if not is_multilingual(datatype) and datatype.multiple:
+                    if separator is not None:
+                        values = [datatype.encode(v) for v in value]
+                        data = separator.join(values)
+                    else:
+                        # TODO represent multiple values
+                        message = ("multiple values are not supported, "
+                                   "use a separator")
+                        raise NotImplementedError, message
+                else:
+                    data = datatype.encode(value)
+                line.append(data)
+            csv.add_row(line)
+
+        return csv
