@@ -126,7 +126,7 @@ skip_content_elements = [
     (text_uri, 'object-count'),
     (text_uri, 'page-continuation'),
     (text_uri, 'page-count'),
-    #(text_uri, 'page-number'),
+    (text_uri, 'page-number'),
     (text_uri, 'page-variable-get'),
     (text_uri, 'page-variable-set'),
     (text_uri, 'paragraph-count'),
@@ -191,6 +191,7 @@ contexts = [
 # XXX These elements appear in openDocuments but they are neither in the doc,
 # nor the relaxNG file!
 unknown_elements = [
+    (style_uri, 'default-page-layout'),
     (style_uri, 'list-level-label-alignment'),
     ]
 
